==> VGAM_0.7-7.tar.gz: VGAM/man/RayleighUC.Rd <==
\name{Rayleigh}
\alias{Rayleigh}
\alias{drayleigh}
\alias{prayleigh}
\alias{qrayleigh}
\alias{rrayleigh}
\title{The Rayleigh Distribution}
\description{
  Density, distribution function, quantile function and random
  generation for the Rayleigh distribution with parameter
  \code{a}.
}
\usage{
drayleigh(x, a)
prayleigh(q, a)
qrayleigh(p, a)
rrayleigh(n, a)
}
\arguments{
  \item{x, q}{vector of quantiles.}
  \item{p}{vector of probabilities.}
  \item{n}{number of observations.
    Must be a positive integer of length 1.}
  \item{a}{the parameter \eqn{a}.}
}
\value{
  \code{drayleigh} gives the density,
  \code{prayleigh} gives the distribution function,
  \code{qrayleigh} gives the quantile function, and
  \code{rrayleigh} generates random deviates.
}
\references{
Evans, M., Hastings, N. and Peacock, B. (2000)
\emph{Statistical Distributions},
New York: Wiley-Interscience, Third edition.
}
\author{ T. W. Yee }
\details{
  See \code{\link{rayleigh}}, the \pkg{VGAM} family function
  for estimating the parameter \eqn{a} by maximum likelihood estimation,
  for the formula of the probability density function and range restrictions
  on the parameter \eqn{a}.

}
\note{
  The Rayleigh distribution is related to the Maxwell distribution.

}
\seealso{
  \code{\link{rayleigh}},
  \code{\link{maxwell}}.
}
\examples{
\dontrun{
a = 2
x = seq(-1, 8, by=0.1)
plot(x, drayleigh(x, a=a), type="l", ylim=c(0,1), las=1, ylab="",
     main="Rayleigh density divided into 10 equal areas; red=cdf")
abline(h=0, col="blue", lty=2)
qq = qrayleigh(seq(0.1,0.9,by=0.1),a=a)
lines(qq, drayleigh(qq, a=a), col="purple", lty=3, type="h")
lines(x, prayleigh(x, a=a), col="red")
}
}
\keyword{distribution}

==> VGAM_0.7-9.tar.gz: VGAM/man/RayleighUC.Rd <==
\name{Rayleigh}
\alias{Rayleigh}
\alias{drayleigh}
\alias{prayleigh}
\alias{qrayleigh}
\alias{rrayleigh}
\title{The Rayleigh Distribution}
\description{
  Density, distribution function, quantile function and random
  generation for the Rayleigh distribution with parameter
  \code{a}.
}
\usage{
drayleigh(x, a, log=FALSE)
prayleigh(q, a)
qrayleigh(p, a)
rrayleigh(n, a)
}
\arguments{
  \item{x, q}{vector of quantiles.}
  \item{p}{vector of probabilities.}
  \item{n}{number of observations.
    Must be a positive integer of length 1.}
  \item{a}{the parameter \eqn{a}.}
  \item{log}{
  Logical.
  If \code{log=TRUE} then the logarithm of the density is returned.

  }

}
\value{
  \code{drayleigh} gives the density,
  \code{prayleigh} gives the distribution function,
  \code{qrayleigh} gives the quantile function, and
  \code{rrayleigh} generates random deviates.
}
\references{
Evans, M., Hastings, N. and Peacock, B. (2000)
\emph{Statistical Distributions},
New York: Wiley-Interscience, Third edition.
}
\author{ T. W. Yee }
\details{
  See \code{\link{rayleigh}}, the \pkg{VGAM} family function
  for estimating the parameter \eqn{a} by maximum likelihood estimation,
  for the formula of the probability density function and range restrictions
  on the parameter \eqn{a}.

}
\note{
  The Rayleigh distribution is related to the Maxwell distribution.

}
\seealso{
  \code{\link{rayleigh}},
  \code{\link{maxwell}}.
}
\examples{
\dontrun{
a = 2
x = seq(-1, 8, by=0.1)
plot(x, drayleigh(x, a=a), type="l", ylim=c(0,1), las=1, ylab="",
     main="Rayleigh density divided into 10 equal areas; red=cdf")
abline(h=0, col="blue", lty=2)
qq = qrayleigh(seq(0.1,0.9,by=0.1),a=a)
lines(qq, drayleigh(qq, a=a), col="purple", lty=3, type="h")
lines(x, prayleigh(x, a=a), col="red")
}
}
\keyword{distribution}
